@@ -63,22 +63,21 @@ theme_nice <- function(legend.pos = "right",
                         base_line_size = base_line_size, 
                         base_rect_size = base_rect_size) %+replace%
     ggplot2::theme(
-      line = element_line(colour = text_and_line_color, size = .5, linetype = 1,
-                          lineend = "butt", arrow = FALSE),
+      line = element_line(colour = text_and_line_color, linewidth = .5,
+                          linetype = 1, lineend = "butt", arrow = FALSE),
       text = element_text(colour = text_and_line_color, face = "plain",
                           family = base_family, 
                           size = 11, hjust = .5, vjust = .5, lineheight = 1,
                           margin = margin(5,5,5,5, "pt"), angle = 0,
                           debug = FALSE),
       rect = element_rect(colour = text_and_line_color, fill = bg_color,
-                          size = .5,
-                          linetype = 1),
+                          linewidth = .5, linetype = 1),
       plot.background = element_rect(fill = all_bg, colour = all_bg),
       plot.title = element_text(face='bold', family = base_family,
                                 margin = margin(10, 5, 10, 5, "pt"),
                                 hjust = 0, size = 14),
       panel.background = element_rect(fill = bg_color, colour = bg_color,
-                                      size = 0),
+                                      linewidth = 0),
       # panel.border = element_blank(),
       axis.title = element_text(face='bold', family = base_family),
       legend.title = element_text(face='bold', family = base_family),
